# Changelog

## [v0.1.0](https://github.com/ncdulo/pywrdgen/tree/v0.1.0) (2020-04-12)

[Full Changelog](https://github.com/ncdulo/pywrdgen/compare/0026cd9a2524938bbf0fc8e8752824a7fa5d915b...v0.1.0), [PyPi](https://pypi.org/project/pywrdgen/0.1.0/)

**Initial release**

- Generate (possibly) secure passwords
- Command line flags to build up character set
- Traditional passwords with options for lowercase, uppercase, numeral, and special characters
- Hexadecimal (upper, or lowercase) output mode
- Generate passwords of a specific, unbounded length
- Generate an unbounded number of passwords
- More verbose, informative mode by default
- Password only mode available by flag. Good for piping into other programs/files
- Packaged for PyPi

\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
